@@ -1,20 +1,8 @@
-/***************************************************************************
- *   Copyright 2008-2010 Stefan Majewsky <majewsky@gmx.net>
- *
- *   This program is free software; you can redistribute it and/or
- *   modify it under the terms of the GNU General Public
- *   License as published by the Free Software Foundation; either
- *   version 2 of the License, or (at your option) any later version.
- *
- *   This program is distributed in the hope that it will be useful,
- *   but WITHOUT ANY WARRANTY; without even the implied warranty of
- *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- *   GNU General Public License for more details.
- *
- *   You should have received a copy of the GNU General Public License
- *   along with this program; if not, write to the Free Software
- *   Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- ***************************************************************************/
+/*
+    SPDX-FileCopyrightText: 2008-2010 Stefan Majewsky <majewsky@gmx.net>
+
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #include "game.h"
 #include "board.h"
@@ -127,7 +115,7 @@ void Game::getMoves()
         }
     }
 #undef C
-    emit numberMoves(m_availableMoves.size());
+    Q_EMIT numberMoves(m_availableMoves.size());
     if (m_availableMoves.isEmpty()) {
         m_board->clearSelection();
         m_gameState->setState(KDiamond::Finished);
@@ -262,7 +250,7 @@ void Game::timerEvent(QTimerEvent *event)
             //all moves may now be out-dated - flush the moves list
             if (!m_availableMoves.isEmpty()) {
                 m_availableMoves.clear();
-                emit numberMoves(-1);
+                Q_EMIT numberMoves(-1);
             }
             //it is now safe to delete the position of the swapping diamonds
             m_swappingDiamonds.clear();
@@ -288,7 +276,7 @@ void Game::timerEvent(QTimerEvent *event)
         }
         break;
     case KDiamond::EndGameJob:
-        emit pendingAnimationsFinished();
+        Q_EMIT pendingAnimationsFinished();
         killTimer(m_timerId);
         m_timerId = -1;
         break;
